@@ -387,5 +387,8 @@ class DashboardsServiceGrpcTransport(DashboardsServiceTransport):
             )
         return self._stubs["update_dashboard"]
 
+    def close(self):
+        self.grpc_channel.close()
+
 
 __all__ = ("DashboardsServiceGrpcTransport",)
