@@ -13,6 +13,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from .alertchart import AlertChart
 from .common import (
     Aggregation,
     PickTimeSeriesFilter,
@@ -49,6 +50,7 @@ from .xychart import (
 )
 
 __all__ = (
+    "AlertChart",
     "Aggregation",
     "PickTimeSeriesFilter",
     "StatisticalTimeSeriesFilter",
